@@ -1,6 +1,6 @@
 package CatalystX::Resource::Controller::Resource;
 {
-    $CatalystX::Resource::Controller::Resource::VERSION = '0.002002';
+    $CatalystX::Resource::Controller::Resource::VERSION = '0.002003';
 }
 use Moose;
 use namespace::autoclean;
@@ -39,6 +39,12 @@ has 'model' => (
     required => 1,
 );
 
+has 'identifier_columns' => (
+    is      => 'ro',
+    isa     => 'ArrayRef',
+    default => sub { [qw/ name title /] },
+);
+
 has 'resultset_key' => (
     is       => 'ro',
     isa      => NonEmptySimpleStr,
@@ -187,39 +193,45 @@ sub _msg {
     }
     elsif ( $action eq 'create' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.created', $self->_name($c) )
-            : $self->_name($c) . " created.";
+            ? $c->loc( 'resources.created', $self->_identifier($c) )
+            : $self->_identifier($c) . " created.";
     }
     elsif ( $action eq 'update' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.updated', $self->_name($c) )
-            : $self->_name($c) . " updated.";
+            ? $c->loc( 'resources.updated', $self->_identifier($c) )
+            : $self->_identifier($c) . " updated.";
     }
     elsif ( $action eq 'delete' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.deleted', $self->_name($c) )
-            : $self->_name($c) . " deleted.";
+            ? $c->loc( 'resources.deleted', $self->_identifier($c) )
+            : $self->_identifier($c) . " deleted.";
     }
     elsif ( $action eq 'move_next' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.moved_next', $self->_name($c) )
-            : $self->_name($c) . " moved next.";
+            ? $c->loc( 'resources.moved_next', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved next.";
     }
     elsif ( $action eq 'move_previous' ) {
         return $c->can('loc')
-            ? $c->loc( 'resources.moved_previous', $self->_name($c) )
-            : $self->_name($c) . " moved previous.";
+            ? $c->loc( 'resources.moved_previous', $self->_identifier($c) )
+            : $self->_identifier($c) . " moved previous.";
     }
 }
 
-sub _name {
+sub _identifier {
     my ( $self, $c ) = @_;
     my $resource = $c->stash->{ $self->resource_key };
-    my $name
-        = $resource->result_source->has_column('name')
-        ? $resource->name
-        : ucfirst( $self->resource_key );
-    return $name;
+
+    for my $col ( @{ $self->identifier_columns } ) {
+        if (   $resource->result_source->has_column($col)
+            && defined $resource->$col
+            && $resource->$col )
+        {
+            return $resource->$col;
+        }
+    }
+
+    return ucfirst( $self->resource_key );
 }
 
 sub base : Chained('') PathPart('') CaptureArgs(0) {
@@ -262,7 +274,7 @@ CatalystX::Resource::Controller::Resource - Base Controller for Resources
 
 =head1 VERSION
 
-version 0.002002
+version 0.002003
 
 =head1 ATTRIBUTES
 
@@ -270,6 +282,19 @@ version 0.002002
 
 required, the DBIC model associated with this resource. (e.g.: 'DB::CDs')
 
+=head2 identifier_columns
+
+ArrayRef of column names used as name in messages.
+
+if you edit, delete, ... a resource a msg is stored in the stash.
+the first defined value of the provided columns will be used.
+
+example: "Resource 'Michael Jackson' has been deleted."
+
+default: [ 'name', 'title' ]
+
+if no identifier is found the resource_key is used
+
 =head2 resultset_key
 
 stash key used to store the resultset of this resource. (e.g.: 'cds_rs')
@@ -318,9 +343,9 @@ redirect request after create/edit/delete/move_next/move_previous
 
 returns notification msg to be displayed
 
-=head2 _name
+=head2 _identifier
 
-get a meaningful name for the resource
+return an identifier for the resource
 
 =head1 ACTIONS
 
